@@ -3,6 +3,6 @@ test_that("logrank works", {
   E1 <- c(1, 1, 1, 0, 1, 0, 1, 0, 0, 1, 1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0)
   T2 <- c(1, 1, 2, 2, 3, 4, 4, 5, 5, 8, 8, 8, 8, 11, 11, 12, 12, 15, 17, 22, 23)
   E2 <- c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1)
-  expect_equal(logrank_test(T1,T2,E1,E2), 4.17e-05)
+  expect_equal(logrank_test(T1,T2,E1,E2), c(1.679294e+01,-4.097919e+00,4.168809e-05), tolerance=1e-5)
 })
 
